from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, Int, String, Float, Directory

Metaquast_Py_V0_1_0 = CommandToolBuilder(tool="metaquast.py", base_command=["metaquast.py"], inputs=[ToolInput(tag="in_output_dir", input_type=Boolean(optional=True), prefix="--output-dir", doc=InputDocumentation(doc="<dirname>       Directory to store all result files [default: quast_results/results_<datetime>]")), ToolInput(tag="in_filenamefilename_commaseparated_list", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="<filename,filename,...>      Comma-separated list of reference genomes or directory with reference genomes")), ToolInput(tag="in_references_list", input_type=File(optional=True), prefix="--references-list", doc=InputDocumentation(doc="Text file with list of reference genome names for downloading from NCBI")), ToolInput(tag="in_features", input_type=Boolean(optional=True), prefix="--features", doc=InputDocumentation(doc="[type:]<filename>  File with genomic feature coordinates in the references (GFF, BED, NCBI or TXT)\nOptional 'type' can be specified for extracting only a specific feature type from GFF")), ToolInput(tag="in_min_contig", input_type=Boolean(optional=True), prefix="--min-contig", doc=InputDocumentation(doc="<int>           Lower threshold for contig length [default: 500]")), ToolInput(tag="in_threads", input_type=Boolean(optional=True), prefix="--threads", doc=InputDocumentation(doc="<int>           Maximum number of threads [default: 25% of CPUs]")), ToolInput(tag="in_split_scaffolds", input_type=Boolean(optional=True), prefix="--split-scaffolds", doc=InputDocumentation(doc="Split assemblies by continuous fragments of N's and add such 'contigs' to the comparison")), ToolInput(tag="in_labels", input_type=Boolean(optional=True), prefix="--labels", doc=InputDocumentation(doc="'label, label, ...'      Names of assemblies to use in reports, comma-separated. If contain spaces, use quotes")), ToolInput(tag="in_take_assembly_names", input_type=Boolean(optional=True), prefix="-L", doc=InputDocumentation(doc="Take assembly names from their parent directory names")), ToolInput(tag="in_eukaryote", input_type=Boolean(optional=True), prefix="--eukaryote", doc=InputDocumentation(doc="Genome is eukaryotic (primarily affects gene prediction)\n--fungus                          Genome is fungal (primarily affects gene prediction)\n--large                           Use optimal parameters for evaluation of large genomes\nIn particular, imposes '-e -m 3000 -i 500 -x 7000' (can be overridden manually)")), ToolInput(tag="in_k_mer_stats", input_type=Boolean(optional=True), prefix="--k-mer-stats", doc=InputDocumentation(doc="Compute k-mer-based quality metrics (recommended for large genomes)\nThis may significantly increase memory and time consumption on large genomes")), ToolInput(tag="in_k_mer_size", input_type=Boolean(optional=True), prefix="--k-mer-size", doc=InputDocumentation(doc="Size of k used in --k-mer-stats [default: 101]\n--circos                          Draw Circos plot")), ToolInput(tag="in_gene_finding", input_type=Boolean(optional=True), prefix="--gene-finding", doc=InputDocumentation(doc="Predict genes using MetaGeneMark\n--glimmer                         Use GlimmerHMM for gene prediction (instead of the default finder, see above)\n--gene-thresholds <int,int,...>   Comma-separated list of threshold lengths of genes to search with Gene Finding module\n[default: 0,300,1500,3000]\n--rna-finding                     Predict ribosomal RNA genes using Barrnap")), ToolInput(tag="in_conserved_genes_finding", input_type=Boolean(optional=True), prefix="--conserved-genes-finding", doc=InputDocumentation(doc="Count conserved orthologs using BUSCO (only on Linux)\n--operons  <filename>             File with operon coordinates in the reference (GFF, BED, NCBI or TXT)\n--max-ref-number <int>            Maximum number of references (per each assembly) to download after looking in SILVA database.\nSet 0 for not looking in SILVA at all [default: 50]\n--blast-db <filename>             Custom BLAST database (.nsq file). By default, MetaQUAST searches references in SILVA database\n--use-input-ref-order             Use provided order of references in MetaQUAST summary plots (default order: by the best average value)\n--contig-thresholds <int,int,...> Comma-separated list of contig length thresholds [default: 0,1000,5000,10000,25000,50000]")), ToolInput(tag="in_use_all_alignments", input_type=Boolean(optional=True), prefix="--use-all-alignments", doc=InputDocumentation(doc="Compute genome fraction, # genes, # operons in QUAST v1.* style.\nBy default, QUAST filters Minimap's alignments to keep only best ones")), ToolInput(tag="in_min_alignment", input_type=Int(optional=True), prefix="--min-alignment", doc=InputDocumentation(doc="The minimum alignment length [default: 65]\n--min-identity <float>            The minimum alignment identity (80.0, 100.0) [default: 95.0]")), ToolInput(tag="in_ambiguity_usage", input_type=String(optional=True), prefix="--ambiguity-usage", doc=InputDocumentation(doc="Use none, one, or all alignments of a contig when all of them\nare almost equally good (see --ambiguity-score) [default: one]")), ToolInput(tag="in_ambiguity_score", input_type=Float(optional=True), prefix="--ambiguity-score", doc=InputDocumentation(doc="Score S for defining equally good alignments of a single contig. All alignments are sorted\nby decreasing LEN * IDY% value. All alignments with LEN * IDY% < S * best(LEN * IDY%) are\ndiscarded. S should be between 0.8 and 1.0 [default: 0.99]")), ToolInput(tag="in_unique_mapping", input_type=Boolean(optional=True), prefix="--unique-mapping", doc=InputDocumentation(doc="Disable --ambiguity-usage=all for the combined reference run,\ni.e. use user-specified or default ('one') value of --ambiguity-usage")), ToolInput(tag="in_strict_na", input_type=Boolean(optional=True), prefix="--strict-NA", doc=InputDocumentation(doc="Break contigs in any misassembly event when compute NAx and NGAx.\nBy default, QUAST breaks contigs only by extensive misassemblies (not local ones)")), ToolInput(tag="in_extensive_mis_size", input_type=Boolean(optional=True), prefix="--extensive-mis-size", doc=InputDocumentation(doc="<int>       Lower threshold for extensive misassembly size. All relocations with inconsistency\nless than extensive-mis-size are counted as local misassemblies [default: 1000]")), ToolInput(tag="in_scaffold_gap_max_size", input_type=Boolean(optional=True), prefix="--scaffold-gap-max-size", doc=InputDocumentation(doc="<int>    Max allowed scaffold gap length difference. All relocations with inconsistency\nless than scaffold-gap-size are counted as scaffold gap misassemblies [default: 10000]")), ToolInput(tag="in_unaligned_part_size", input_type=Boolean(optional=True), prefix="--unaligned-part-size", doc=InputDocumentation(doc="<int>      Lower threshold for detecting partially unaligned contigs. Such contig should have\nat least one unaligned fragment >= the threshold [default: 500]")), ToolInput(tag="in_skip_unaligned_mis_contigs", input_type=Boolean(optional=True), prefix="--skip-unaligned-mis-contigs", doc=InputDocumentation(doc="Do not distinguish contigs with >= 50% unaligned bases as a separate group\nBy default, QUAST does not count misassemblies in them")), ToolInput(tag="in_fragmented", input_type=Boolean(optional=True), prefix="--fragmented", doc=InputDocumentation(doc="Reference genome may be fragmented into small pieces (e.g. scaffolded reference)\n--fragmented-max-indent  <int>    Mark translocation as fake if both alignments are located no further than N bases\nfrom the ends of the reference fragments [default: 85]\nRequires --fragmented option\n--upper-bound-assembly            Simulate upper bound assembly based on the reference genome and reads\n--upper-bound-min-con  <int>      Minimal number of 'connecting reads' needed for joining upper bound contigs into a scaffold\n[default: 2 for mate-pairs and 1 for long reads]\n--est-insert-size  <int>          Use provided insert size in upper bound assembly simulation [default: auto detect from reads or 255]\n--plots-format  <str>             Save plots in specified format [default: pdf].\nSupported formats: emf, eps, pdf, png, ps, raw, rgba, svg, svgz\n--memory-efficient                Run everything using one thread, separately per each assembly.\nThis may significantly reduce memory consumption on large genomes\n--space-efficient                 Create only reports and plots files. Aux files including .stdout, .stderr, .coords will not be created.\nThis may significantly reduce space consumption on large genomes. Icarus viewers also will not be built")), ToolInput(tag="in_pe_one", input_type=Boolean(optional=True), prefix="--pe1", doc=InputDocumentation(doc="<filename>              File with forward paired-end reads (in FASTQ format, may be gzipped)")), ToolInput(tag="in_pe_two", input_type=Boolean(optional=True), prefix="--pe2", doc=InputDocumentation(doc="<filename>              File with reverse paired-end reads (in FASTQ format, may be gzipped)\n--pe12    <filename>              File with interlaced forward and reverse paired-end reads. (in FASTQ format, may be gzipped)\n--mp1     <filename>              File with forward mate-pair reads (in FASTQ format, may be gzipped)\n--mp2     <filename>              File with reverse mate-pair reads (in FASTQ format, may be gzipped)\n--mp12    <filename>              File with interlaced forward and reverse mate-pair reads (in FASTQ format, may be gzipped)\n--single  <filename>              File with unpaired short reads (in FASTQ format, may be gzipped)\n--pacbio     <filename>           File with PacBio reads (in FASTQ format, may be gzipped)\n--nanopore   <filename>           File with Oxford Nanopore reads (in FASTQ format, may be gzipped)\n--ref-sam <filename>              SAM alignment file obtained by aligning reads to reference genome file\n--ref-bam <filename>              BAM alignment file obtained by aligning reads to reference genome file\n--sam     <filename,filename,...> Comma-separated list of SAM alignment files obtained by aligning reads to assemblies\n(use the same order as for files with contigs)\n--bam     <filename,filename,...> Comma-separated list of BAM alignment files obtained by aligning reads to assemblies\n(use the same order as for files with contigs)\nReads (or SAM/BAM file) are used for structural variation detection and\ncoverage histogram building in Icarus\n--sv-bedpe  <filename>            File with structural variations (in BEDPE format)")), ToolInput(tag="in_no_check", input_type=Boolean(optional=True), prefix="--no-check", doc=InputDocumentation(doc="Do not check and correct input fasta files. Use at your own risk (see manual)")), ToolInput(tag="in_no_plots", input_type=Boolean(optional=True), prefix="--no-plots", doc=InputDocumentation(doc="Do not draw plots")), ToolInput(tag="in_no_html", input_type=Boolean(optional=True), prefix="--no-html", doc=InputDocumentation(doc="Do not build html reports and Icarus viewers")), ToolInput(tag="in_no_icarus", input_type=Boolean(optional=True), prefix="--no-icarus", doc=InputDocumentation(doc="Do not build Icarus viewers")), ToolInput(tag="in_no_snps", input_type=Boolean(optional=True), prefix="--no-snps", doc=InputDocumentation(doc="Do not report SNPs (may significantly reduce memory consumption on large genomes)")), ToolInput(tag="in_no_gc", input_type=Boolean(optional=True), prefix="--no-gc", doc=InputDocumentation(doc="Do not compute GC% and GC-distribution")), ToolInput(tag="in_no_sv", input_type=Boolean(optional=True), prefix="--no-sv", doc=InputDocumentation(doc="Do not run structural variation detection (make sense only if reads are specified)")), ToolInput(tag="in_no_gzip", input_type=Boolean(optional=True), prefix="--no-gzip", doc=InputDocumentation(doc="Do not compress large output files")), ToolInput(tag="in_no_read_stats", input_type=Boolean(optional=True), prefix="--no-read-stats", doc=InputDocumentation(doc="Do not align reads to assemblies\nReads will be aligned to reference and used for coverage analysis,\nupper bound assembly simulation, and structural variation detection.\nUse this option if you do not need read statistics for assemblies.")), ToolInput(tag="in_fast", input_type=Boolean(optional=True), prefix="--fast", doc=InputDocumentation(doc="A combination of all speedup options except --no-check")), ToolInput(tag="in_silent", input_type=Boolean(optional=True), prefix="--silent", doc=InputDocumentation(doc="Do not print detailed information about each step to stdout (log file is not affected)")), ToolInput(tag="in_test", input_type=Directory(optional=True), prefix="--test", doc=InputDocumentation(doc="Run MetaQUAST on the data from the test_data folder, output to quast_test_output")), ToolInput(tag="in_test_no_ref", input_type=Directory(optional=True), prefix="--test-no-ref", doc=InputDocumentation(doc="Run MetaQUAST without references on the data from the test_data folder, output to quast_test_output.\nMetaQUAST will download SILVA 16S rRNA database (~170 Mb) for searching reference genomes\nInternet connection is required")), ToolInput(tag="in_python", input_type=String(), position=0, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_test", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_test", type_hint=File()), doc=OutputDocumentation(doc="Run MetaQUAST on the data from the test_data folder, output to quast_test_output")), ToolOutput(tag="out_test_no_ref", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_test_no_ref", type_hint=File()), doc=OutputDocumentation(doc="Run MetaQUAST without references on the data from the test_data folder, output to quast_test_output.\nMetaQUAST will download SILVA 16S rRNA database (~170 Mb) for searching reference genomes\nInternet connection is required"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Metaquast_Py_V0_1_0().translate("wdl", allow_empty_container=True)

